pyshred.objects package
=======================

Submodules
----------

pyshred.objects.dataset module
------------------------------

.. automodule:: pyshred.objects.dataset
   :members:
   :undoc-members:
   :show-inheritance:

pyshred.objects.sindy module
----------------------------

.. automodule:: pyshred.objects.sindy
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyshred.objects
   :members:
   :undoc-members:
   :show-inheritance:
